=== modified file 'NEWS'
--- NEWS	2009-06-11 09:11:21 +0000
+++ NEWS	2009-06-12 01:11:00 +0000
@@ -20,6 +20,25 @@
 New Features
 ************
 
+* A new repository format ``2a`` has been added.  This is a beta release
+  of the the brisbane-core (aka group-compress) project.  This format now
+  suitable for wider testing by advanced users willing to deal with some
+  bugs.  We would appreciate test reports, either positive or negative.
+  Format 2a is substantially smaller and faster for many operations on
+  many trees.  This format or an updated version will become the default
+  in bzr 2.0.
+
+  This is a rich-root format, so this repository format can be used with
+  bzr-svn.  Bazaar branches in previous non-rich-root formats can be
+  converted (including by merge, push and pull) to format 2a, but not vice
+  versa.  We recommend upgrading previous development formats to 2a.
+
+  Upgrading to this format can take considerable time because it expands
+  and more concisely repacks the full history.
+
+  If you use stacked branches, you must upgrade the stacked branches
+  before the stacked-on branches.  (See <https://bugs.launchpad.net/bugs/374735>)
+
 * ``--development7-rich-root`` is a new dev format, similar to ``--dev6``
   but using a Revision serializer using bencode rather than XML.
   (Jelmer Vernooij, John Arbash Meinel)

=== modified file 'bzrlib/bzrdir.py'
--- bzrlib/bzrdir.py	2009-06-11 11:02:53 +0000
+++ bzrlib/bzrdir.py	2009-06-12 01:11:00 +0000
@@ -3831,6 +3831,18 @@
     experimental=True,
     )
 
+format_registry.register_metadir('2a',
+    'bzrlib.repofmt.groupcompress_repo.RepositoryFormat2a',
+    help='First format for bzr 2.0 series.\n'
+        'Uses group-compress storage.\n'
+        'Provides rich roots which are a one-way transition.\n',
+        # 'storage in packs, 255-way hashed CHK inventory, bencode revision, group compress, '
+        # 'rich roots. Supported by bzr 1.16 and later.',
+    branch_format='bzrlib.branch.BzrBranchFormat7',
+    tree_format='bzrlib.workingtree.WorkingTreeFormat6',
+    experimental=True,
+    )
+
 # The following format should be an alias for the rich root equivalent 
 # of the default format
 format_registry.register_metadir('default-rich-root',

=== modified file 'bzrlib/repofmt/groupcompress_repo.py'
--- bzrlib/repofmt/groupcompress_repo.py	2009-06-11 23:43:13 +0000
+++ bzrlib/repofmt/groupcompress_repo.py	2009-06-12 01:11:00 +0000
@@ -1069,3 +1069,21 @@
                 'revision serialization (needs bzr.dev from 1.16)\n')
 
 
+class RepositoryFormat2a(RepositoryFormatCHK2):
+    """A CHK repository that uses the bencode revision serializer.
+    
+    This is the same as RepositoryFormatCHK2 but with a public name.
+    """
+
+    _serializer = chk_serializer.chk_bencode_serializer
+
+    def _get_matching_bzrdir(self):
+        return bzrdir.format_registry.make_bzrdir('2a')
+
+    def _ignore_setting_bzrdir(self, format):
+        pass
+
+    _matchingbzrdir = property(_get_matching_bzrdir, _ignore_setting_bzrdir)
+
+    def get_format_string(self):
+        return ('Bazaar repository format 2a (needs bzr 1.16 or later)\n')

=== modified file 'bzrlib/repository.py'
--- bzrlib/repository.py	2009-06-11 23:43:13 +0000
+++ bzrlib/repository.py	2009-06-12 01:11:00 +0000
@@ -3066,6 +3066,11 @@
     'bzrlib.repofmt.groupcompress_repo',
     'RepositoryFormatCHK2',
     )
+format_registry.register_lazy(
+    'Bazaar repository format 2a (needs bzr 1.16 or later)\n',
+    'bzrlib.repofmt.groupcompress_repo',
+    'RepositoryFormat2a',
+    )
 
 
 class InterRepository(InterObject):

=== modified file 'bzrlib/tests/blackbox/test_init.py'
--- bzrlib/tests/blackbox/test_init.py	2009-03-23 14:59:43 +0000
+++ bzrlib/tests/blackbox/test_init.py	2009-06-11 04:04:14 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2006, 2007 Canonical Ltd
+# Copyright (C) 2006, 2007, 2009 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -49,6 +49,13 @@
             out)
         self.assertEqual('', err)
 
+    def test_init_format_2a(self):
+        """Smoke test for constructing a format 2a repoistory."""
+        out, err = self.run_bzr('init --format=2a')
+        self.assertEqual("""Created a standalone tree (format: 2a)\n""",
+            out)
+        self.assertEqual('', err)
+
     def test_init_at_repository_root(self):
         # bzr init at the root of a repository should create a branch
         # and working tree even when creation of working trees is disabled.

